@@ -1,5 +1,6 @@
 use anyhow::anyhow;
 use anyhow::bail;
+use anyhow::Context as AnyhowContext;
 use anyhow::Result;
 use parking_lot::Mutex;
 use serde::de::DeserializeOwned;
@@ -102,7 +103,7 @@ impl ProcessPluginCommunicator {
       .stderr(Stdio::piped())
       .stdout(Stdio::piped())
       .spawn()
-      .map_err(|err| anyhow!("Error starting {} with args [{}]. {}", executable_file_path.display(), args.join(" "), err))?;
+      .map_err(|err| anyhow!("Error starting {} with args [{}]. {:#}", executable_file_path.display(), args.join(" "), err))?;
 
     // read and output stderr prefixed
     let stderr = child.stderr.take().unwrap();
@@ -119,7 +120,8 @@ impl ProcessPluginCommunicator {
     let mut stdout_reader = MessageReader::new(child.stdout.take().unwrap());
     let mut stdin_writer = MessageWriter::new(child.stdin.take().unwrap());
 
-    verify_plugin_schema_version(&mut stdout_reader, &mut stdin_writer)?;
+    verify_plugin_schema_version(&mut stdout_reader, &mut stdin_writer)
+      .context("Failed plugin schema verification. This may indicate you are using an old version of the dprint CLI or plugin and should upgrade.")?;
 
     let (message_tx, message_rx) = crossbeam_channel::unbounded::<Message>();
     let context = Context {
@@ -139,7 +141,7 @@ impl ProcessPluginCommunicator {
         loop {
           if let Err(err) = read_stdout_message(&mut stdout_reader, &context) {
             if !context.poisoner.is_poisoned() && !context.shutdown_flag.is_raised() {
-              on_std_err(format!("Error reading stdout message: {}", err));
+              on_std_err(format!("Error reading stdout message: {:#}", err));
             }
             break;
           }
@@ -171,8 +173,11 @@ impl ProcessPluginCommunicator {
     } else {
       // attempt to exit nicely
       tokio::select! {
+        // we wait for acknowledgement in order to give the process
+        // plugin a chance to clean up (ex. in case it has spawned
+        // any processes it needs to kill or something like that)
         _ = self.send_with_acknowledgement(MessageBody::Close) => {}
-        _ = tokio::time::sleep(Duration::from_millis(100)) => {}
+        _ = tokio::time::sleep(Duration::from_millis(250)) => {}
       }
       self.context.poisoner.poison();
     }
@@ -315,7 +320,7 @@ impl ProcessPluginCommunicator {
           Ok(data) => Ok(data),
           Err(err) => {
             self.context.poisoner.poison();
-            bail!("Error waiting on message ({}). {}", message_id, err)
+            bail!("Error waiting on message ({}). {:#}", message_id, err)
           }
         }
       }
@@ -327,21 +332,17 @@ fn verify_plugin_schema_version<TRead: Read + Unpin, TWrite: Write + Unpin>(
   reader: &mut MessageReader<TRead>,
   writer: &mut MessageWriter<TWrite>,
 ) -> Result<()> {
-  writer.send_u32(0)?; // ask for schema version
-  writer.flush()?;
-  if reader.read_u32()? != 0 {
-    bail!(concat!(
-      "There was a problem checking the plugin schema version. ",
-      "This may indicate you are using an old version of the dprint CLI or plugin and should upgrade."
-    ));
+  // since this is the setup, use a lot of contexts to find exactly where it failed
+  writer.send_u32(0).context("Failed asking for schema version.")?; // ask for schema version
+  writer.flush().context("Failed flushing schema version request.")?;
+  let acknowledgement_response = reader.read_u32().context("Could not read success response.")?;
+  if acknowledgement_response != 0 {
+    bail!("Plugin response was unexpected ({acknowledgement_response}).");
   }
-  let plugin_schema_version = reader.read_u32()?;
+  let plugin_schema_version = reader.read_u32().context("Could not read schema version.")?;
   if plugin_schema_version != PLUGIN_SCHEMA_VERSION {
     bail!(
-      concat!(
-        "The plugin schema version was {}, but expected {}. ",
-        "This may indicate you are using an old version of the dprint CLI or plugin and should upgrade."
-      ),
+      "The plugin schema version was {}, but expected {}.",
       plugin_schema_version,
       PLUGIN_SCHEMA_VERSION
     );
@@ -364,7 +365,7 @@ fn std_err_redirect(poisoner: Poisoner, shutdown_flag: ArcFlag, stderr: ChildStd
           poisoner.poison();
           return;
         } else {
-          on_std_err(format!("Error reading line from process plugin stderr. {}", err));
+          on_std_err(format!("Error reading line from process plugin stderr. {:#}", err));
         }
       }
     }
@@ -449,7 +450,7 @@ fn read_stdout_message(reader: &mut MessageReader<ChildStdout>, context: &Contex
             }),
             Err(err) => MessageBody::Error(ResponseBody {
               message_id: message.id,
-              data: format!("{}", err).into_bytes(),
+              data: format!("{:#}", err).into_bytes(),
             }),
           },
         });
